@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -34,6 +34,8 @@
 #include "htmlcolor.h"
 #include "htmlcolorset.h"
 #include "htmlsettings.h"
+#include "gtkhtml-private.h"
+
 #include "body.h"
 #include "properties.h"
 #include "utils.h"
@@ -48,7 +50,6 @@ struct _GtkHTMLEditBodyProperties {
 };
 typedef struct _GtkHTMLEditBodyProperties GtkHTMLEditBodyProperties;
 
-#define TEMPLATES 9
 typedef struct {
 	gchar *name;
 	gchar *bg_pixmap;
@@ -58,7 +59,7 @@ typedef struct {
 	gint left_margin;
 } BodyTemplate;
 
-static BodyTemplate body_templates [TEMPLATES] = {
+static BodyTemplate body_templates[] = {
 	{
 		N_("None"),
 		NULL,
@@ -69,7 +70,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
 	},
 	{
 		N_("Perforated paper"),
-		ICONDIR "/paper.png",
+		"paper.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0x3380, 0x6680},
@@ -77,7 +78,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
 	},
 	{
 		N_("Blue ink"),
-		ICONDIR "/texture.png",
+		"texture.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0x1fff, 0x1fff, 0x8fff},
 		{0, 0, 0, 0xffff},
@@ -85,7 +86,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
 	},
 	{
 		N_("Paper"),
-		ICONDIR "/rect.png",
+		"rect.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -93,7 +94,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Ribbon"),
-		ICONDIR "/ribbon.jpg",
+		"ribbon.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0x9900, 0x3300, 0x6600},
@@ -101,7 +102,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Midnight"),
-		ICONDIR "/midnight-stars.jpg",
+		"midnight-stars.jpg",
 		{0, 0, 0, 0},
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0xffff, 0x9900, 0},
@@ -109,7 +110,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Confidential"),
-		ICONDIR "/confidential-stamp.jpg",
+		"confidential-stamp.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -117,7 +118,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Draft"),
-		ICONDIR "/draft-stamp.jpg",
+		"draft-stamp.jpg",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0},
 		{0, 0, 0, 0xffff},
@@ -125,7 +126,7 @@ static BodyTemplate body_templates [TEMPLATES] = {
   	},
 	{
 		N_("Graph paper"),
-		ICONDIR "/draft-paper.png",
+		"draft-paper.png",
 		{0, 0xffff, 0xffff, 0xffff},
 		{0, 0, 0, 0x8000},
 		{0, 0xe300, 0x2100, 0x2300},
@@ -162,9 +163,9 @@ entry_changed (GtkWidget *w, GtkHTMLEditBodyProperties *data)
 		e->bgPixmapPtr = NULL;
 	}
 
-	fname = gtk_entry_get_text (GTK_ENTRY (w));
+	fname = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
 	if (fname && *fname) {
-		gchar *file = g_strconcat ("file:", fname, NULL);
+		gchar *file = gtk_html_filename_to_uri (fname);
 
 		e->bgPixmapPtr = html_image_factory_register (e->image_factory, NULL, file, TRUE);
 		g_free (file);
@@ -173,14 +174,19 @@ entry_changed (GtkWidget *w, GtkHTMLEditBodyProperties *data)
 }
 
 static void
-changed_template (GtkWidget *w, GtkHTMLEditBodyProperties *d)
+changed_template (GtkComboBox *combo_box, GtkHTMLEditBodyProperties *d)
 {
 	gint template, left_margin = 10;
+	gchar *filename;
 
-	template = g_list_index (GTK_MENU_SHELL (w)->children, gtk_menu_get_active (GTK_MENU (w)));
+	template = gtk_combo_box_get_active (combo_box);
 
-	gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->pixmap_entry))),
-			    body_templates [template].bg_pixmap ? body_templates [template].bg_pixmap : "");
+	filename = (body_templates [template].bg_pixmap ?
+		    g_build_filename (ICONDIR, body_templates [template].bg_pixmap, NULL) :
+		    g_strdup (""));
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER ((d->pixmap_entry)),
+			    filename);
+	g_free (filename);
 
 	if (template) {
 		gi_color_combo_set_color (GI_COLOR_COMBO (d->combo [2]), &body_templates [template].bg_color);
@@ -206,30 +212,11 @@ changed_template (GtkWidget *w, GtkHTMLEditBodyProperties *d)
 	d->cd->html->engine->leftBorder = left_margin;
 }
 
-static void
-fill_templates (GtkHTMLEditBodyProperties *d)
-{
-	GtkWidget *menu;
-	gint i;
-
-	menu = gtk_menu_new ();
-
-	for (i = 0; i < TEMPLATES; i ++) {
-		GtkWidget *item;
-
-		item = gtk_menu_item_new_with_label (_(body_templates [i].name));
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-		gtk_widget_show (item);
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (d->option_template), menu);
-}
-
 GtkWidget *
 body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 {
 	GtkHTMLEditBodyProperties *data = g_new0 (GtkHTMLEditBodyProperties, 1);
 	GtkWidget *main_vbox, *hbox, *combo, *label, *t1;
-	GSList *group;
 	HTMLColor *color;
 	gint i;
 
@@ -239,32 +226,10 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	main_vbox = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
 
-	t1 = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
-	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
-
-	data->option_template = gtk_option_menu_new ();
-	atk_object_set_name (gtk_widget_get_accessible (data->option_template), _("Template"));
-	fill_templates (data);
-	hbox = gtk_hbox_new (FALSE, 1);
-	gtk_box_pack_start (GTK_BOX (hbox), data->option_template, FALSE, FALSE, 0);
-	editor_hig_attach_row (t1, _("T_emplate:"), hbox, 0);
-	
-	/* data->entry_title = gtk_entry_new ();
-	if (gtk_html_get_title (data->cd->html)) {
-		gtk_entry_set_text (GTK_ENTRY (data->entry_title), 
-				    gtk_html_get_title (data->cd->html));
-	}
-	g_signal_connect (data->entry_title, "changed", G_CALLBACK (entry_changed), data);
-	editor_hig_attach_row (t1, _("T_itle:"), data->entry_title, 1);	*/
-
-	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("General"), t1), FALSE, FALSE, 0);
-
 	t1 = gtk_table_new (3, 2, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
 	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
 
-	group = NULL;
 	i = 0;
 #define ADD_COLOR(x, ct, g) \
         color = html_colorset_get_color (cd->html->engine->settings->color_set, ct); \
@@ -277,6 +242,7 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	hbox = gtk_hbox_new (FALSE, 3); \
         label = gtk_label_new_with_mnemonic (x); \
         gtk_misc_set_alignment (GTK_MISC (label), .0, .5); \
+        atk_object_add_relationship (gtk_widget_get_accessible (GI_COLOR_COMBO(combo)->preview_button), ATK_RELATION_LABELLED_BY, gtk_widget_get_accessible (label)); \
         gtk_table_attach (GTK_TABLE (t1), label, 0, 1, i, i + 1, GTK_FILL, GTK_FILL, 0, 0); \
         gtk_table_attach (GTK_TABLE (t1), combo, 1, 2, i, i + 1, GTK_FILL, GTK_FILL, 0, 0); \
         i ++
@@ -287,26 +253,39 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 
 	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Colors"), t1), FALSE, FALSE, 0);
 
-	data->pixmap_entry = gnome_pixmap_entry_new ("background_image", _("Background Image"), FALSE);
+	data->pixmap_entry = gtk_file_chooser_button_new (_("Background Image"), GTK_FILE_CHOOSER_ACTION_OPEN);
 	if (cd->html->engine->bgPixmapPtr) {
 		HTMLImagePointer *ip = (HTMLImagePointer *) cd->html->engine->bgPixmapPtr;
-		guint off = 0;
-		 if (!strncmp (ip->url, "file:", 5))
-			 off = 5;
-
-		 gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry))),
-				     ip->url + off);
+		gchar *filename = gtk_html_filename_from_uri (ip->url);
+		
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER ((data->pixmap_entry)),
+				    filename);
+		g_free (filename);
 	}
 
 
-	atk_object_set_name (gtk_widget_get_accessible (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (data->pixmap_entry))), _("Background Image File Path"));
+	atk_object_set_name (gtk_widget_get_accessible (data->pixmap_entry), _("Background Image File Path"));
+
+	t1 = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
+	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
 
 	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new_with_mnemonic (_("_Source:")), FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), data->pixmap_entry, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Background Image"), hbox), FALSE, FALSE, 0);
+	data->option_template = gtk_combo_box_new_text ();
+	atk_object_set_name (gtk_widget_get_accessible (data->option_template), _("Template"));
+	for (i = 0; i < G_N_ELEMENTS (body_templates); i++)
+		gtk_combo_box_append_text (
+			GTK_COMBO_BOX (data->option_template),
+			gettext (body_templates[i].name));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->option_template), 0);
+	gtk_box_pack_start (GTK_BOX (hbox), data->option_template, FALSE, FALSE, 0);
+	editor_hig_attach_row (t1, _("T_emplate:"), hbox, 0);
 
-	/* gtk_idle_add (hide_preview, data); */
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), data->pixmap_entry, TRUE, TRUE, 0);
+	editor_hig_attach_row (t1, _("C_ustom:"), hbox, 1);
+
+	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Background Image"), t1), FALSE, FALSE, 0);
 
 	/* set ui */
 #define SET_COLOR(ct) \
@@ -319,13 +298,12 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	/* connect signal handlers */
 	gtk_widget_show_all (main_vbox);
 
-	g_signal_connect (gtk_option_menu_get_menu (GTK_OPTION_MENU (data->option_template)),
-			  "selection-done", G_CALLBACK (changed_template), data);
+	g_signal_connect (data->option_template, "changed", G_CALLBACK (changed_template), data);
         g_signal_connect (data->combo [0], "color_changed", G_CALLBACK (color_changed), data);
         g_signal_connect (data->combo [1], "color_changed", G_CALLBACK (color_changed), data);
         g_signal_connect (data->combo [2], "color_changed", G_CALLBACK (color_changed), data);
-	g_signal_connect (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry)),
-			  "changed", G_CALLBACK (entry_changed), data);
+	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (data->pixmap_entry),
+			  "selection-changed", G_CALLBACK (entry_changed), data);
 
 	return main_vbox;
 }
