@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Author: Ettore Perazzoli <ettore@helixcode.com>
 */
@@ -33,12 +33,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#ifdef USE_GTKFILECHOOSER
 #include <gtk/gtkfilechooser.h>
 #include <gtk/gtkfilechooserdialog.h>
-#else
-#include <gtk/gtkfilesel.h>
-#endif
 #include <bonobo.h>
 
 #include "htmlengine.h"
@@ -67,6 +63,8 @@ static void smiley_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const cha
 static void font_style_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname);
 static void command_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname);
 
+static gboolean get_file_charset (const gchar * filename, gchar *charset, gint len);
+
 static void
 paste_quotation_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 {
@@ -97,7 +95,6 @@ insert_image_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cna
 	GtkWidget *filesel;
 	HTMLObject *img;
 
-#ifdef USE_GTKFILECHOOSER
 	filesel = gtk_file_chooser_dialog_new (_("Insert image"),
 					       NULL,
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -105,25 +102,11 @@ insert_image_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cna
 					       GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					       NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
-#else
-	filesel = gtk_file_selection_new (_("Insert image"));
-#endif
 	if (filesel) {
 		if (gtk_dialog_run (GTK_DIALOG (filesel)) == GTK_RESPONSE_OK) {
-#ifdef USE_GTKFILECHOOSER
-			char *filename;
-#else
-			const char *filename;
-#endif
 			char *url = NULL;
 
-#ifdef USE_GTKFILECHOOSER
-			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
-#else
-			filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
-#endif
-			url = gtk_html_filename_to_uri (filename);
-			g_free(filename);
+			url = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (filesel));
 			img = html_image_new (html_engine_get_image_factory (cd->html->engine), url,
 					      NULL, NULL, 0, 0, 0, 0, 0, NULL, HTML_VALIGN_NONE, FALSE);
 			html_engine_paste_object (cd->html->engine, img, 1);
@@ -222,13 +205,9 @@ file_dialog_ok (GtkWidget *w, GtkHTMLControlData *cd)
 	GError *error = NULL;
 	gchar *data = NULL;
 	gsize len = 0;
-	const char *charset;
+	gchar charset[32];
 
-#ifdef USE_GTKFILECHOOSER
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (cd->file_dialog));
-#else	
-	filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (cd->file_dialog));
-#endif
 	io = g_io_channel_new_file (filename, "r", &error);
 
 	if (error || !io)
@@ -238,24 +217,28 @@ file_dialog_ok (GtkWidget *w, GtkHTMLControlData *cd)
 	g_io_channel_read_to_end (io, &data, &len, &error);
 
 	/* If we get a charset error try reading as the locale charset */
-	if (error && g_error_matches (error, G_CONVERT_ERROR, G_CONVERT_ERROR_ILLEGAL_SEQUENCE)
-	    && !g_get_charset (&charset)) {
-
-		g_error_free (error);
-		error = NULL;
+	if (error && g_error_matches (error, G_CONVERT_ERROR, G_CONVERT_ERROR_ILLEGAL_SEQUENCE)) {
 
 		/* 
-		 * reopen the io channel since we can't set the 
+		 * Close the io channel since we can't set the 
 		 * charset once we've begun reading.
 		 */
 		g_io_channel_unref (io);
-		io = g_io_channel_new_file (filename, "r", &error);
+		io = NULL;
+
+		if (get_file_charset (filename, charset, 32)) {
+
+			g_error_free (error);
+			error = NULL;
+
+			io = g_io_channel_new_file (filename, "r", &error);
 		
-		if (error || !io)
-			goto end;
-		
-		g_io_channel_set_encoding (io, charset, NULL);
-		g_io_channel_read_to_end (io, &data, &len, &error);
+			if (error || !io)
+				goto end;
+
+			g_io_channel_set_encoding (io, charset, NULL);
+			g_io_channel_read_to_end (io, &data, &len, &error);
+		}
 	}
 	
 	if (error)
@@ -316,7 +299,6 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 		return;
 	}
 
-#ifdef USE_GTKFILECHOOSER
 	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert HTML File") : _("Insert Text File"),
 						       NULL,
 						       GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -325,10 +307,6 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 						       NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (cd->file_dialog), GTK_RESPONSE_OK);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (cd->file_dialog), g_get_home_dir ());
-#else
-	cd->file_dialog = gtk_file_selection_new (html ? _("Insert HTML File") : _("Insert Text File"));
-	gtk_file_selection_set_filename (GTK_FILE_SELECTION (cd->file_dialog), "~/");
-#endif
 
 	if (cd->file_dialog) {
 		if (gtk_dialog_run (GTK_DIALOG (cd->file_dialog)) == GTK_RESPONSE_OK) {
@@ -701,20 +679,20 @@ smiley_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 		case 1: /* smile */
 			emoticon = ":)";
 			break;
-		case 2: /* wink */
-			emoticon = ";)";
-			break;
-		case 3: /* surprised */
+		case 2: /* surprised */
 			emoticon = "=)";
 			break;
-		case 4: /* laughing */
-			emoticon = ":D";
+		case 3: /* wink */
+			emoticon = ";)";
+			break;
+		case 4: /* frown */
+			emoticon = ":(";
 			break;
 		case 5: /* oh no! */
 			emoticon = ":O";
 			break;
-		case 6: /* frown */
-			emoticon = ":(";
+		case 6: /* laughing */
+			emoticon = ":D";
 			break;
 		case 8: /* indifferent */
 			emoticon = ":-|";
@@ -900,3 +878,44 @@ menubar_setup (BonoboUIComponent  *uic,
 	}
 }
 
+gboolean 
+get_file_charset (const gchar * filename, gchar *charset, gint len)
+{
+	char data[1024];
+	gboolean result = FALSE;
+	FILE *fp = fopen (filename, "r");
+	
+	if (!fp)
+		return FALSE;
+
+
+	while (fgets (data, sizeof(data)-1, fp)) {
+
+		char * pos = strstr (g_ascii_strdown (data, -1), "charset");
+		if (pos) {
+			gchar * pos2 = strstr (pos, "=");
+			if (pos2) {
+				pos2++;
+				gchar * word = pos2;
+				while (*pos2) {
+					if (*pos2 != '"')
+						pos2++;
+					else
+					{
+						if (pos2 - word < len) {
+							g_strlcpy (charset, word, pos2 - word + 1);
+							result = TRUE;
+						}
+						break;
+					}
+				}
+				break;
+			}
+		}
+	}
+
+	fclose (fp);
+
+
+	return result;
+}
