@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h> 
@@ -26,8 +26,6 @@
 #else
 #include <glib/gi18n.h>
 #endif
-#include <gnome.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include "search.h"
 #include "dialog.h"
 #include "htmlengine-search.h"
@@ -107,7 +105,7 @@ gtk_html_search_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 {
 	GtkHTMLSearchDialog *dialog = g_new (GtkHTMLSearchDialog, 1);
 	GtkWidget *hbox, *vbox;
-	char *filename;
+
 	/* we use CANCEL response for close, because we want Esc to close the dialog - see gtkdialog.c */
 	dialog->dialog         = GTK_DIALOG (gtk_dialog_new_with_buttons (_("Find"), NULL, 0,
 									  GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
@@ -143,9 +141,7 @@ gtk_html_search_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 	gtk_widget_show (dialog->entry);
 	gtk_widget_show_all (hbox);
 
-	filename = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_search", 16, NULL, NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog->dialog), filename);
-	g_free(filename);
+	gtk_window_set_icon_name (GTK_WINDOW (dialog->dialog), "gtk-find");
 
 	gtk_widget_grab_focus (dialog->entry);
 
@@ -171,7 +167,8 @@ gtk_html_search_dialog_destroy (GtkHTMLSearchDialog *d)
 void
 search (GtkHTMLControlData *cd)
 {
-	RUN_DIALOG (search, _("Find"));
+	run_dialog (&cd->search_dialog->dialog, cd->html, cd,
+		(DialogCtor) gtk_html_search_dialog_new, _("Find"));
 }
 
 void
