@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 
    Author: Radek Doulik <rodo@helixcode.com>
 
@@ -227,6 +227,8 @@ typedef enum {
 	GTK_HTML_COMMAND_UNBLOCK_SELECTION,
 
 	GTK_HTML_COMMAND_IS_SELECTION_ACTIVE,
+	GTK_HTML_COMMAND_SCROLL_FORWARD,
+	GTK_HTML_COMMAND_SCROLL_BACKWARD,
 } GtkHTMLCommandType;
 
 typedef enum {
