@@ -15,8 +15,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /* Various debugging routines.  */
@@ -291,8 +291,6 @@ gtk_html_debug_dump_object (HTMLObject *obj,
 		g_print ("Location: %s\n", HTML_IMAGE (obj)->image_ptr->url);
 		break;
 	case HTML_TYPE_FRAMESET: {
-		gint i;
-
 		for (i = 0; i < HTML_FRAMESET (obj)->frames->len; i++)
 			gtk_html_debug_dump_tree (g_ptr_array_index (HTML_FRAMESET (obj)->frames, i), level + 1);
 		}
