@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -45,7 +45,7 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
     HTMLClueAligned *tmp;
 	HTMLObject *obj;
 
-    tmp = 0;
+    tmp = NULL;
     obj = cluev->align_left_list;
 
     while ( obj ) {
@@ -56,7 +56,7 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
 			} else {
 				cluev->align_left_list
 					= HTML_OBJECT (HTML_CLUEALIGNED (obj)->next_aligned);
-				tmp = 0;
+				tmp = NULL;
 			}
 		} else {
 			tmp = HTML_CLUEALIGNED (obj);
@@ -65,7 +65,7 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
 		obj = HTML_OBJECT (HTML_CLUEALIGNED (obj)->next_aligned);
     }
 
-    tmp = 0;
+    tmp = NULL;
     obj = cluev->align_right_list;
 
     while ( obj ) {
@@ -76,7 +76,7 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
 			} else {
 				cluev->align_right_list
 					= HTML_OBJECT (HTML_CLUEALIGNED (obj)->next_aligned);
-				tmp = 0;
+				tmp = NULL;
 			}
 		} else {
 			tmp = HTML_CLUEALIGNED (obj);
@@ -349,7 +349,8 @@ set_max_height (HTMLObject *o, HTMLPainter *painter, gint height)
 {
 	HTMLClue *clue = HTML_CLUE (o);
 
-	html_object_calc_size (o, painter, NULL);
+	/* Is it necessary to calc size here? It doesn't seem to. */
+	/* html_object_calc_size (o, painter, NULL); */
 	if (o->ascent < height) {
 		(* HTML_OBJECT_CLASS (parent_class)->set_max_height) (o, painter, height);
 		clue->curr = NULL;
@@ -570,7 +571,7 @@ relayout (HTMLObject *self,
 
 	if (child == NULL)
 		child = HTML_CLUE (self)->head;
-	html_object_calc_size (child, engine->painter, FALSE);
+	html_object_calc_size (child, engine->painter, NULL);
 
 	HTML_CLUE (self)->curr = NULL;
 
@@ -578,7 +579,7 @@ relayout (HTMLObject *self,
 	prev_ascent = self->ascent;
 	prev_descent = self->descent;
 
-	changed = html_cluev_do_layout (self, engine->painter, FALSE, FALSE);
+	changed = html_cluev_do_layout (self, engine->painter, FALSE, NULL);
 	if (changed)
 		html_engine_queue_draw (engine, self);
 
@@ -892,6 +893,22 @@ html_cluev_real_get_direction (HTMLObject *o)
 	return HTML_CLUEV (o)->dir;
 }
 
+static void
+html_cluev_destroy (HTMLObject *self)
+{
+	HTMLClueV *cluev = HTML_CLUEV (self);
+
+	if (cluev->border_color)
+		html_color_unref (cluev->border_color);
+	cluev->border_color = NULL;
+
+	if (cluev->background_color)
+		html_color_unref (cluev->background_color);
+	cluev->background_color = NULL;
+
+	(* HTML_OBJECT_CLASS (parent_class)->destroy) (self);
+}
+
 
 void
 html_cluev_type_init (void)
@@ -925,6 +942,7 @@ html_cluev_class_init (HTMLClueVClass *klass,
 	object_class->get_left_margin = get_left_margin;
 	object_class->get_right_margin = get_right_margin;
 	object_class->get_direction = html_cluev_real_get_direction;
+	object_class->destroy = html_cluev_destroy;
 
 	clue_class->get_left_clear = get_left_clear;
 	clue_class->get_right_clear = get_right_clear;
@@ -957,10 +975,10 @@ html_cluev_init (HTMLClueV *cluev,
 	clue->valign = HTML_VALIGN_BOTTOM;
 	clue->halign = HTML_HALIGN_NONE;
 	cluev->dir = HTML_DIRECTION_DERIVED;
-	clue->head = clue->tail = clue->curr = 0;
+	clue->head = clue->tail = clue->curr = NULL;
 
-	cluev->align_left_list = 0;
-	cluev->align_right_list = 0;
+	cluev->align_left_list = NULL;
+	cluev->align_right_list = NULL;
 	cluev->padding = 0;
 	cluev->border_style = HTML_BORDER_NONE;
 	cluev->border_width = 0;
@@ -986,6 +1004,9 @@ html_cluev_set_style (HTMLClueV *cluev, HTMLStyle *style)
 		if (cluev->border_color)
 			html_color_unref (cluev->border_color);
 
+		if (cluev->background_color)
+			html_color_unref (cluev->background_color);
+
 		cluev->padding = style->padding;
 
 		cluev->border_style = style->border_style;
@@ -1001,7 +1022,7 @@ html_cluev_set_style (HTMLClueV *cluev, HTMLStyle *style)
 		if (cluev->border_color)
 			html_color_unref (cluev->border_color);
 
-		if (cluev->border_color)
+		if (cluev->background_color)
 			html_color_unref (cluev->background_color);
 
 		cluev->border_style = HTML_BORDER_NONE;
