@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLENGINE_EDIT_CLUEFLOW_STYLE_H
@@ -30,7 +30,9 @@ gboolean           html_engine_set_clueflow_style                (HTMLEngine
 								  HTMLListType                    item_type,
 								  HTMLHAlignType                  alignment,
 								  gint                            indentation_delta,
+								  guint8                         *indentation_levels,
 								  HTMLEngineSetClueFlowStyleMask  mask,
+								  HTMLUndoDirection               dir,
 								  gboolean                        do_undo);
 
 void               html_engine_get_current_clueflow_style        (HTMLEngine                     *engine,
