@@ -12,8 +12,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -327,7 +327,7 @@ draw_page_cb (GtkPrintOperation *operation, GtkPrintContext *context,
 
 	metrics = pango_context_get_metrics (
 		pango_layout_get_context (layout),
-		desc, pango_language_get_default ());
+		desc, gtk_get_default_language ());
 	footer_height = (pango_font_metrics_get_ascent (metrics) +
 		pango_font_metrics_get_descent (metrics)) / PANGO_SCALE;
 	pango_font_metrics_unref (metrics);
